@@ -56,9 +56,12 @@
 use serde_json::value::Map;
 use serde_json::value::Value;
 
+pub use error::Error;
+
 pub mod error;
 
 /// Enum to specify how arrays are formatted.
+#[derive(Clone, Debug, Eq, PartialEq)]
 pub enum ArrayFormatting {
     /// Uses only the key separator. Example:  `{"a": ["b"]}` => `{"a.0": "b"}`
     Plain,
@@ -71,6 +74,7 @@ pub enum ArrayFormatting {
 
 /// Basic struct of this crate. It contains the configuration. Instantiate it and use the method
 /// `flatten` to flatten a JSON object.
+#[derive(Clone, Debug, Eq, PartialEq)]
 pub struct Flattener {
     /// String used to separate the keys after the object it's flattened
     key_separator: String,
@@ -129,6 +133,26 @@ impl Flattener {
         self
     }
 
+    #[must_use]
+    pub fn key_separator(&self) -> &str {
+        &self.key_separator
+    }
+
+    #[must_use]
+    pub fn array_formatting(&self) -> &ArrayFormatting {
+        &self.array_formatting
+    }
+
+    #[must_use]
+    pub fn preserve_empty_arrays(&self) -> bool {
+        self.preserve_empty_arrays
+    }
+
+    #[must_use]
+    pub fn preserve_empty_objects(&self) -> bool {
+        self.preserve_empty_objects
+    }
+
     /// Flattens the provided JSON object (`current`).
     ///
     /// It will return an error if flattening the object would make two keys to be the same,
